Changes for bmi-topography
==========================

0.7 (2022-03-24)
----------------

- Support all OpenTopography global datasets (#39)
- Create test matrix of datasets and file types (#38)


0.6 (2022-02-17)
----------------

- Use dashes in command line options (#36)
- Use a demo API key if a user key can't be found (#34)


0.5.1 (2022-02-15)
------------------

- Document use of OpenTopography API key (#33)
- Add text to exception raised when API key is missing (#32)
- Use new black syntax (#31)


0.5 (2022-01-25)
----------------

- Use an API key when requesting OpenTopography data (#25)
- Add python 3.10 to tests (#24)
- Address technical debt (#22)


0.4 (2021-09-03)
----------------

- Support ALOS World 3D 30m products (#13)
- Support .asc and .img files (#14)
- Add format job to CI
- Use CITATION.cff file


0.3.2 (2021-04-23)
------------------

- Add citation recommendation with DOI
- Fix typos, update text in example notebooks
- Create CREDITS.md and rearrange docs


0.3.1 (2021-03-04)
------------------

- Install with conda
- Include shell script demonstrating CLI


0.3 (2021-02-25)
----------------

- Update README with overview and install instructions
- Write documentation


0.2 (2021-02-24)
----------------

- Implement BMI for Topography class from template generated by `bmipy-render`
- Include sample config file and Jupyter Notebook to demo BMI
- Add CI with GitHub Actions


0.1.1 (2021-02-22)
------------------

- Add Makefile rule to test upload to TestPyPI
- Test upload to TestPyPI


0.1 (2021-02-22)
----------------

- Create base library that calls OpenTopography API
- Create CLI for library
- Write tests for library and CLI
- Include demo Jupyter Notebook for library
